summaryrefslogtreecommitdiff
path: root/src/simulation/elements
diff options
context:
space:
mode:
authorjacob1 <jfu614@gmail.com>2013-05-14 01:10:45 (GMT)
committer jacob1 <jfu614@gmail.com>2013-05-14 01:10:45 (GMT)
commit7856f727a5b7d88904752267d4a1decd66ecbf4e (patch)
treecce09602f7d9ac4ddabc4ff203e24b7740c4a744 /src/simulation/elements
parent8aa9f96843abfdc8ca619412032f2d2c78fe3ccc (diff)
downloadpowder-7856f727a5b7d88904752267d4a1decd66ecbf4e.zip
powder-7856f727a5b7d88904752267d4a1decd66ecbf4e.tar.gz
rename TUGN to TUNG (more popular spelling). Broken BRMT smelts back into TUGN
Diffstat (limited to 'src/simulation/elements')
-rw-r--r--src/simulation/elements/BRMT.cpp2
-rw-r--r--src/simulation/elements/DMG.cpp2
-rw-r--r--src/simulation/elements/SPRK.cpp2
-rw-r--r--src/simulation/elements/TUNG.cpp (renamed from src/simulation/elements/TUGN.cpp)27
4 files changed, 17 insertions, 16 deletions
diff --git a/src/simulation/elements/BRMT.cpp b/src/simulation/elements/BRMT.cpp
index cf4f99d..c2556ea 100644
--- a/src/simulation/elements/BRMT.cpp
+++ b/src/simulation/elements/BRMT.cpp
@@ -40,7 +40,7 @@ Element_BRMT::Element_BRMT()
LowTemperature = ITL;
LowTemperatureTransition = NT;
HighTemperature = 1273.0f;
- HighTemperatureTransition = PT_LAVA;
+ HighTemperatureTransition = ST;
Update = &Element_BRMT::update;
diff --git a/src/simulation/elements/DMG.cpp b/src/simulation/elements/DMG.cpp
index 4f1daaf..4612d77 100644
--- a/src/simulation/elements/DMG.cpp
+++ b/src/simulation/elements/DMG.cpp
@@ -92,7 +92,7 @@ int Element_DMG::update(UPDATE_FUNC_ARGS)
sim->part_change_type(rr>>8, x+nxi, y+nxj, PT_BCOL);
else if(t == PT_QRTZ)
sim->part_change_type(rr>>8, x+nxi, y+nxj, PT_PQRT);
- else if(t == PT_TUGN)
+ else if(t == PT_TUNG)
sim->part_change_type(rr>>8, x+nxi, y+nxj, PT_BRMT);
}
}
diff --git a/src/simulation/elements/SPRK.cpp b/src/simulation/elements/SPRK.cpp
index 15fd0e4..a8b40f7 100644
--- a/src/simulation/elements/SPRK.cpp
+++ b/src/simulation/elements/SPRK.cpp
@@ -158,7 +158,7 @@ int Element_SPRK::update(UPDATE_FUNC_ARGS)
}
}
break;
- case PT_TUGN:
+ case PT_TUNG:
if(parts[i].temp < 3595.0){
parts[i].temp += (rand()%20)-4;
}
diff --git a/src/simulation/elements/TUGN.cpp b/src/simulation/elements/TUNG.cpp
index 4fb8032..1666346 100644
--- a/src/simulation/elements/TUGN.cpp
+++ b/src/simulation/elements/TUNG.cpp
@@ -1,10 +1,10 @@
#include "simulation/Elements.h"
#include "simulation/Air.h"
-//#TPT-Directive ElementClass Element_TUGN PT_TUGN 171
-Element_TUGN::Element_TUGN()
+//#TPT-Directive ElementClass Element_TUNG PT_TUNG 171
+Element_TUNG::Element_TUNG()
{
- Identifier = "DEFAULT_PT_TUGN";
- Name = "TUGN";
+ Identifier = "DEFAULT_PT_TUNG";
+ Name = "TUNG";
Colour = PIXPACK(0x505050);
MenuVisible = 1;
MenuSection = SC_ELEC;
@@ -29,7 +29,7 @@ Element_TUGN::Element_TUGN()
Temperature = R_TEMP+0.0f +273.15f;
HeatConduct = 251;
- Description = "Brittle metal with a very high melting point.";
+ Description = "Tungsten. Brittle metal with a very high melting point.";
State = ST_SOLID;
Properties = TYPE_SOLID|PROP_CONDUCTS|PROP_LIFE_DEC;
@@ -45,15 +45,15 @@ Element_TUGN::Element_TUGN()
/*HighTemperature = 3895.0f;
HighTemperatureTransition = PT_LAVA;*/
- Update = &Element_TUGN::update;
- Graphics = &Element_TUGN::graphics;
+ Update = &Element_TUNG::update;
+ Graphics = &Element_TUNG::graphics;
}
#define MELTING_POINT 3695.0
-//#TPT-Directive ElementHeader Element_TUGN static int update(UPDATE_FUNC_ARGS)
-int Element_TUGN::update(UPDATE_FUNC_ARGS)
+//#TPT-Directive ElementHeader Element_TUNG static int update(UPDATE_FUNC_ARGS)
+int Element_TUNG::update(UPDATE_FUNC_ARGS)
{
bool splode = false;
if(parts[i].temp > 2400.0)
@@ -85,7 +85,7 @@ int Element_TUGN::update(UPDATE_FUNC_ARGS)
else
{
sim->part_change_type(i, x, y, PT_LAVA);
- parts[i].ctype = PT_TUGN;
+ parts[i].ctype = PT_TUNG;
return 1;
}
if(splode)
@@ -101,13 +101,14 @@ int Element_TUGN::update(UPDATE_FUNC_ARGS)
if (parts[i].pavg[1]-parts[i].pavg[0] > 0.50f || parts[i].pavg[1]-parts[i].pavg[0] < -0.50f)
{
sim->part_change_type(i,x,y,PT_BRMT);
+ parts[i].ctype = PT_TUNG;
}
return 0;
}
-//#TPT-Directive ElementHeader Element_TUGN static int graphics(GRAPHICS_FUNC_ARGS)
-int Element_TUGN::graphics(GRAPHICS_FUNC_ARGS)
+//#TPT-Directive ElementHeader Element_TUNG static int graphics(GRAPHICS_FUNC_ARGS)
+int Element_TUNG::graphics(GRAPHICS_FUNC_ARGS)
{
double startTemp = (MELTING_POINT - 1500.0);
double tempOver = (((cpart->temp - startTemp)/1500.0)*M_PI) - (M_PI/2.0);
@@ -129,4 +130,4 @@ int Element_TUGN::graphics(GRAPHICS_FUNC_ARGS)
return 0;
}
-Element_TUGN::~Element_TUGN() {}
+Element_TUNG::~Element_TUNG() {}